@@ -25,56 +25,49 @@ class DescribeSuspEventQuaraFilesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeSuspEventQuaraFiles')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SourceIp(self):
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_PageSize(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_PageSize(self): # String
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_From(self):
+	def set_PageSize(self, PageSize):  # String
+		self.add_query_param('PageSize', PageSize)
+	def get_From(self): # String
 		return self.get_query_params().get('From')
 
-	def set_From(self,_From):
-		self.add_query_param('From',_From)
-
-	def get_GroupingId(self):
+	def set_From(self, _From):  # String
+		self.add_query_param('From', _From)
+	def get_GroupingId(self): # Long
 		return self.get_query_params().get('GroupingId')
 
-	def set_GroupingId(self,GroupingId):
-		self.add_query_param('GroupingId',GroupingId)
-
-	def get_GroupId(self):
+	def set_GroupingId(self, GroupingId):  # Long
+		self.add_query_param('GroupingId', GroupingId)
+	def get_GroupId(self): # String
 		return self.get_query_params().get('GroupId')
 
-	def set_GroupId(self,GroupId):
-		self.add_query_param('GroupId',GroupId)
-
-	def get_CurrentPage(self):
+	def set_GroupId(self, GroupId):  # String
+		self.add_query_param('GroupId', GroupId)
+	def get_CurrentPage(self): # String
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_QuaraTag(self):
+	def set_CurrentPage(self, CurrentPage):  # String
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_QuaraTag(self): # String
 		return self.get_query_params().get('QuaraTag')
 
-	def set_QuaraTag(self,QuaraTag):
-		self.add_query_param('QuaraTag',QuaraTag)
-
-	def get_Status(self):
+	def set_QuaraTag(self, QuaraTag):  # String
+		self.add_query_param('QuaraTag', QuaraTag)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
